mcpcalcRatioBFGS(object, CMn, CMd, control=mcprofileControl(), margin=NULL)mcprofileControl.NULL no extra margin is considered.steps correspond to the number of values evaluated around the
MLE, alphamax defines the maximal cutoff value by choosing a
quantile of a normal distribution at 1-alphamax divided by the number of
rows of the contrast matrix, if fixed.range is TRUE the
deviance is evaluated at equal-sized steps in a range provided by the
margin argument.optim, profile.glm, sci.ratio, interpSpline, contrMatRatio